@@ -4,11 +4,11 @@
 # hide rows without setting each one, (of approximately 1 million rows),
 # Excel uses an optimisation to hide all rows that don't have data.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('hide_row_col.xlsx')
+workbook = xlsxwriter.Workbook('hide_row_col.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Write some data.
