@@ -6,12 +6,12 @@
 # This program is shown, with explanations, in Tutorial 2 of the XlsxWriter
 # documentation.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
 # Create a workbook and add a worksheet.
-workbook = Workbook('Expenses02.xlsx')
+workbook = xlsxwriter.Workbook('Expenses02.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Add a bold format to use to highlight cells.
