@@ -41,6 +41,18 @@ class ChartScatter(chart.Chart):
         self.val_axis_postion = 'b'
         self.smooth_allowed = True
 
+        # Set the available data label positions for this chart type.
+        self.label_position_default = 'right'
+        self.label_positions = {
+            'center': 'ctr',
+            'right': 'r',
+            'left': 'l',
+            'above': 't',
+            'below': 'b',
+            # For backward compatibility.
+            'top': 't',
+            'bottom': 'b'}
+
     ###########################################################################
     #
     # Private API.
