@@ -106,6 +106,7 @@ class Workbook(xmlwriter.XMLwriter):
         self.tab_ratio = 500
         self.str_table = SharedStringTable()
         self.vba_project = None
+        self.vba_is_stream = False
         self.vba_codename = None
         self.image_types = {}
         self.images = []
@@ -212,7 +213,7 @@ class Workbook(xmlwriter.XMLwriter):
         """
 
         # Type must be specified so we can create the required chart instance.
-        chart_type = options.get('type', 'None')
+        chart_type = options.get('type')
         if chart_type is None:
             warn("Chart type must be defined in add_chart()")
             return
@@ -250,6 +251,25 @@ class Workbook(xmlwriter.XMLwriter):
 
         return chart
 
+    def add_vba_project(self, vba_project, is_stream=False):
+        """
+        Add a vbaProject binary to the Excel workbook.
+
+        Args:
+            vba_project: The vbaProject binary file name.
+            is_stream:   vba_project is an in memory byte stream.
+
+        Returns:
+            Nothing.
+
+        """
+        if not is_stream and not os.path.exists(vba_project):
+            warn("VBA project binary file '%s' not found." % vba_project)
+            return -1
+
+        self.vba_project = vba_project
+        self.vba_is_stream = is_stream
+
     def close(self):
         """
         Call finalisation code and close file.
@@ -387,6 +407,23 @@ class Workbook(xmlwriter.XMLwriter):
         """
         self.allow_zip64 = True
 
+    def set_vba_name(self, name=None):
+        """
+        Set the VBA name for the workbook. By default the workbook is referred
+        to as ThisWorkbook in VBA.
+
+        Args:
+            name: The VBA name for the workbook.
+
+        Returns:
+            Nothing.
+
+        """
+        if name is not None:
+            self.vba_codename = name
+        else:
+            self.vba_codename = 'ThisWorkbook'
+
     ###########################################################################
     #
     # Private API.
@@ -1132,6 +1169,7 @@ class Workbook(xmlwriter.XMLwriter):
         vml_shape_id = 1024
         vml_files = 0
         comment_files = 0
+        has_button = False
 
         for sheet in self.worksheets():
             if not sheet.has_vml and not sheet.has_header_vml:
@@ -1164,12 +1202,25 @@ class Workbook(xmlwriter.XMLwriter):
             self.num_vml_files = vml_files
             self.num_comment_files = comment_files
 
+            if len(sheet.buttons_list):
+                has_button = True
+
+                # Set the sheet vba_codename if it has a button and the
+                # workbook has a vbaProject binary.
+                if self.vba_project and sheet.vba_codename is None:
+                    sheet.set_vba_name()
+
         # Add a font format for cell comments.
         if comment_files > 0:
             xf = self.add_format({'font_name': 'Tahoma', 'font_size': 8,
                                   'color_indexed': 81, 'font_only': True})
             xf._get_xf_index()
 
+        # Set the workbook vba_codename if one of the sheets has a button and
+        # the workbook has a vbaProject binary.
+        if has_button and self.vba_project and self.vba_codename is None:
+            self.set_vba_name()
+
     def _prepare_tables(self):
         # Set the table ids for the worksheet tables.
         table_id = 0
